"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import type { ExtendedClient } from "@/types";
import type { Client } from "@prisma/client";

import {
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
} from "@/components/ui/alert-dialog";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";

interface ClientStatusToggleProps {
  client: Client | ExtendedClient;
}

export function ClientStatusToggle({ client }: ClientStatusToggleProps) {
  const router = useRouter();
  const [isLoading, setIsLoading] = useState(false);
  const [showDialog, setShowDialog] = useState(false);

  const handleToggle = async () => {
    try {
      setIsLoading(true);
      const response = await fetch(`/api/admin/clients/${client.id}/status`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          enabled: !client.enabled,
        }),
      });

      if (!response.ok) {
        throw new Error("Failed to update client status");
      }

      router.refresh();
    } catch (error) {
      console.error("Error updating client status:", error);
    } finally {
      setIsLoading(false);
      setShowDialog(false);
    }
  };

  return (
    <>
      <Badge
        variant={client.enabled ? "default" : "destructive"}
        className="cursor-pointer"
        onClick={() => setShowDialog(true)}
      >
        {client.enabled ? "启用" : "禁用"}
      </Badge>

      <AlertDialog open={showDialog} onOpenChange={setShowDialog}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>
              确定要{client.enabled ? "禁用" : "启用"}该应用吗？
            </AlertDialogTitle>
            <AlertDialogDescription>
              {client.enabled
                ? "禁用后，该应用将无法使用 OAuth 服务，所有已授权的用户将无法访问。"
                : "启用后，该应用将恢复使用 OAuth 服务的权限。"}
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel disabled={isLoading}>取消</AlertDialogCancel>
            <AlertDialogAction
              onClick={handleToggle}
              disabled={isLoading}
              className={client.enabled ? "bg-destructive" : undefined}
            >
              确定
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </>
  );
}
